@@ -8,7 +8,8 @@ format.p <- function(p, lab=FALSE, labval="p", noblanks=FALSE,
                          ifelse(p < 0.0001,
                                 paste(labval, " < 0", outdec, "0001", sep=""),
                                 paste(paste(labval, "="),
-                                      formatC(round(p, digits), decimal.mark=outdec)
+                                      formatC(round(p, digits), decimal.mark = outdec,
+                                              format = "f", digits = digits)
                                       )
                                 )
                          )
@@ -17,7 +18,8 @@ format.p <- function(p, lab=FALSE, labval="p", noblanks=FALSE,
     res <- format(ifelse(is.na(p), "      --",
                          ifelse(p < 0.0001,
                                 paste("< 0", outdec, "0001", sep=""),
-                                paste(" ", formatC(round(p, digits), decimal.mark=outdec)
+                                paste(" ", formatC(round(p, digits), decimal.mark = outdec,
+                                                   format = "f", digits = digits)
                                       )
                                 )
                          )
